.. highlight:: shell

============
Installation
============


Stable release
--------------

To install OpenQTSim, run this command in your terminal:

.. code-block:: bash

    # Use pip to install OpenQTSim
    pip install openqtsim

This is the preferred method to install OpenQTSim, as it will always install the most recent stable release.

If you do not `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From sources
------------

The sources for OpenQTSim can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: bash

    # Use git to clone OpenQTSim
    git clone git://github.com/TUDelft-CITG/OpenQTSim


Or download the `tarball`_:

.. code-block:: bash

    # Use curl to obtain the tarball
    curl  -OL https://github.com/TUDelft-CITG/OpenQTSim/tarball/master


Once you have a copy of the source, you can install it with:

.. code-block:: bash

    # Use python to install
    python setup.py install


.. _Github repo: https://github.com/TUDelft-CITG/OpenQTSim
.. _tarball: https://github.com/TUDelft-CITG/OpenQTSim/tarball/master
